==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/expression/impl/EnumeratorReferenceSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.EnumeratorReference;
import io.ciera.tool.sql.architecture.expression.EnumeratorReferenceSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;
import io.ciera.tool.sql.architecture.type.EnumeratorSet;
import io.ciera.tool.sql.architecture.type.impl.EnumeratorSetImpl;

import java.util.Arrays;
import java.util.List;


public class EnumeratorReferenceSetImpl extends InstanceSet<EnumeratorReferenceSet,EnumeratorReference> implements EnumeratorReferenceSet {

    // attributes
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setBlock_number( ref_block_number );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setParent_name( ref_parent_name );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setStatement_number( ref_statement_number );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setBody_name( ref_body_name );
    }
    @Override
    public void setEnum_type_name( String ref_enum_type_name ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setEnum_type_name( ref_enum_type_name );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setParent_package( ref_parent_package );
    }
    @Override
    public void setEnum_name( String ref_enum_name ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setEnum_name( ref_enum_name );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setExpression_number( ref_expression_number );
    }
    @Override
    public void setEnum_type_package( String ref_enum_type_package ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setEnum_type_package( ref_enum_type_package );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( EnumeratorReference enumeratorreference : this ) expressionset.add( enumeratorreference.R776_is_a_Expression() );
        return expressionset;
    }
    @Override
    public EnumeratorSet R786_refers_to_Enumerator() throws XtumlException {
        EnumeratorSet enumeratorset = new EnumeratorSetImpl();
        for ( EnumeratorReference enumeratorreference : this ) enumeratorset.add( enumeratorreference.R786_refers_to_Enumerator() );
        return enumeratorset;
    }


    @Override
    public EnumeratorReference nullElement() {
        return EnumeratorReferenceImpl.EMPTY_ENUMERATORREFERENCE;
    }

    @Override
    public EnumeratorReferenceSet emptySet() {
      return new EnumeratorReferenceSetImpl();
    }

    @Override
    public EnumeratorReferenceSet value() {
        return this;
    }

    @Override
    public List<EnumeratorReference> elements() {
        return Arrays.asList(toArray(new EnumeratorReference[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/expression/impl/EnumeratorReferenceSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.EnumeratorReference;
import io.ciera.tool.sql.architecture.expression.EnumeratorReferenceSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;
import io.ciera.tool.sql.architecture.type.EnumeratorSet;
import io.ciera.tool.sql.architecture.type.impl.EnumeratorSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class EnumeratorReferenceSetImpl extends InstanceSet<EnumeratorReferenceSet,EnumeratorReference> implements EnumeratorReferenceSet {

    public EnumeratorReferenceSetImpl() {
    }

    public EnumeratorReferenceSetImpl(Comparator<? super EnumeratorReference> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setParent_name( ref_parent_name );
    }
    @Override
    public void setEnum_type_name( String ref_enum_type_name ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setEnum_type_name( ref_enum_type_name );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setBlock_number( ref_block_number );
    }
    @Override
    public void setEnum_name( String ref_enum_name ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setEnum_name( ref_enum_name );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setBody_name( ref_body_name );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setParent_package( ref_parent_package );
    }
    @Override
    public void setEnum_type_package( String ref_enum_type_package ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setEnum_type_package( ref_enum_type_package );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setExpression_number( ref_expression_number );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( EnumeratorReference enumeratorreference : this ) enumeratorreference.setStatement_number( ref_statement_number );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( EnumeratorReference enumeratorreference : this ) expressionset.add( enumeratorreference.R776_is_a_Expression() );
        return expressionset;
    }
    @Override
    public EnumeratorSet R786_refers_to_Enumerator() throws XtumlException {
        EnumeratorSet enumeratorset = new EnumeratorSetImpl();
        for ( EnumeratorReference enumeratorreference : this ) enumeratorset.add( enumeratorreference.R786_refers_to_Enumerator() );
        return enumeratorset;
    }


    @Override
    public EnumeratorReference nullElement() {
        return EnumeratorReferenceImpl.EMPTY_ENUMERATORREFERENCE;
    }

    @Override
    public EnumeratorReferenceSet emptySet() {
      return new EnumeratorReferenceSetImpl();
    }

    @Override
    public EnumeratorReferenceSet emptySet(Comparator<? super EnumeratorReference> comp) {
      return new EnumeratorReferenceSetImpl(comp);
    }

    @Override
    public EnumeratorReferenceSet value() {
        return this;
    }

    @Override
    public List<EnumeratorReference> elements() {
        return Arrays.asList(toArray(new EnumeratorReference[0]));
    }

}
